@@ -3,6 +3,8 @@
 use File::Find 'find';
 use MP3::Info;
 
+$MP3::Info::try_harder = 1;
+
 my (@f,$r);
 $r = shift if @ARGV and $ARGV[0] eq '-r';
 
@@ -17,7 +19,7 @@ die "No files found" unless @f;
 my $t = 0;
 for my $f (@f) {
   my $info = get_mp3info($f);
-  warn("No mp3info for `$f'...\n"), next unless defined $info;
+  warn("No mp3info for `$f': $@\n"), next unless defined $info;
   $t += $info->{SECS}
 }
 #my @l = `mp3info -p "%S\n" @f`;
